==> western-world-3.0.644.tgz: package/src/defs/remove_credit/remove_credit.js <==
const style = require('!!css-loader!sass-loader!./remove_credit.scss').default;

export const remove_credit = `
<symbol id="remove_credit" x="0px" y="0px" viewBox="0 0 8192 8192">
    <style type="text/css">
        .remove_credit_st1{fill:#321414;}
        .remove_credit_st2{fill:#321414;}
        .remove_credit_st3{fill:#F6D5A9;}
        .remove_credit_st4{fill:#704415;}
        .remove_credit_st5{opacity:0.2;}
        .remove_credit_st6{opacity:5.000000e-02;}
        .remove_credit_st7{fill:#494B4D;}
        .remove_credit_st8{fill:#FFFFFF;}
        .remove_credit_st9{fill:#C20C2C;}
        .remove_credit_st10{fill:#9E9E9E;}
        .remove_credit_st11{fill:#592919;}
        .remove_credit_st12{fill:#7B594C;}
        .remove_credit_st13{fill:#965e4f;}
        ${style}
    </style>
    <defs>
        <mask id="window-mask">
            <path fill="white" d="M1883.8,5121c0,0,1.3-379.8,0-1265.8c-3.5-2332.7,2992-2302.3,2980.5-222.7c-7.9,1430.1,0,1488.5,0,1488.5 H1883.8z"/>
        </mask>
    </defs>
    <g id="remove_credit-main-container">
        <g id="remove_credit_background">
            <circle cx="4096" cy="4096" r="3700" fill="white" />
            <circle cx="4096" cy="4096" r="3700" fill="url(#bricks_pattern)" />
            <circle cx="4096" cy="4096" r="3700" fill="white" opacity="0.4" />
        </g>
        <g id="remove_credit_teller_window">
            <path class="remove_credit_st1" d="M1883.8,5121c0,0,1.3-379.8,0-1265.8c-3.5-2332.7,2992-2302.3,2980.5-222.7c-7.9,1430.1,0,1488.5,0,1488.5 H1883.8z"/>
        </g>
        <g id="remove_credit_title">
            <path class="remove_credit_st2" d="M2676.6,1931.7c16.7,30.1,8.2,66.7-25.6,109.7c-32.7,41.3-80.2,79.3-142.6,113.9c-28.3,15.7-55,28.3-80.3,37.6 c-25.2,9.4-49.8,15.6-73.7,18.7l-128.7-231.8c25.6-21.5,51.1-41.4,76.4-59.6c25.3-18.2,51.9-35,79.7-50.5 c47.9-26.6,87.7-42.5,119.4-47.8c34.9-5.8,58.1,1.6,69.5,22.1c4.7,8.5,4.6,19-0.5,31.3c-5.1,12.3-21,33.5-47.7,63.6 c34.4-16.3,65.6-25.6,93.7-28C2647.3,1908.4,2667.4,1915.3,2676.6,1931.7z M2445.7,1918.9c-4.1-7.3-11.9-10.2-23.5-8.6 c-11.6,1.6-25.1,6.7-40.5,15.2c-18.3,10.1-32.3,20.6-42,31.4l26,46.8c5.2-0.6,11.2-2.8,18.1-6.7c18.7-10.4,35-23.7,48.8-40 C2446.4,1940.8,2450.8,1928.1,2445.7,1918.9z M2544.9,2010.2c-3.9-7.1-12.7-10.2-26.2-9.5c-13.6,0.7-26.8,4.7-39.7,11.9 c-4,2.2-7.9,4.9-11.7,8l29,52.2c4.1-1.6,9.2-4.1,15.4-7.6c14.7-8.2,25.1-17.3,31.1-27.5C2548.7,2027.5,2549.4,2018.4,2544.9,2010.2 z"/>
            <path class="remove_credit_st2" d="M3310,1851.4l-155.1,94l-76.4-56.4l-90.1,37.3l-44,78.9l-172.2-13.6l121.6-347l135.3-9.5L3310,1851.4z M3065.6,1835.2l-82.3-96.1l-22.1,121.1L3065.6,1835.2z"/>
            <path class="remove_credit_st2" d="M3865.1,1956.8l-244-224.4l44.7,173.8l-241.9-22.6l62.5-328.8l258.5,174.6l-14-139.1l187.9,83.5L3865.1,1956.8 z"/>
            <path class="remove_credit_st2" d="M4475.6,2163.3l-137.6,12.7l-120.7-201.7l-27.3,75.2l-205.6-75.7l134.7-283.2l205,94.7l-80,77.5l221.8-27 l66.2,117.1l-184.5,15.1L4475.6,2163.3z"/>
        </g>
        <g id="remove_credit_person">
            <g id="remove_credit_head">
                <path class="remove_credit_st3" d="M5164.7,2551c0,0,290.3,611.6,414.6,1275.5l867-209.2c0,0-124.3-568.4-257.7-868.5c0,0,77.3,1.5,83.4-103.1 s-111.9-108.5-162.2-83.4c-33.3,16.7-45.5,59.1-45.5,59.1s-45.5-280.4-168.3-369.9c-122.8-89.4-289.5,15.2-347.1,80.3 S5304.9,2559.3,5164.7,2551z"/>
                <path class="remove_credit_st4" d="M4988.1,2217c0,0-105.2,27.3-84.9,213.5c13.6,125.1,169,148.5,169,148.5s78.2,228.1,207.9,243.1 c0,0-102.9-254.1-115.4-271.1c0,0,97.4,16.7,255.4-106.1c158-122.8,201.2-227.4,386.5-226.2c185.3,1.1,257.7,402.8,257.7,402.8 s15.9-73.1,102.1-71.9c0,0,55.6-347.8-118.8-502.6c-90.9-80.7-203.5-38.7-203.5-38.7s-45.5-172.8-291-148.9 c-200.3,19.5-383.1,303.5-411.5,386.5C5113.2,2328.9,4966.5,2360.9,4988.1,2217z"/>
                <path class="remove_credit_st5" d="M6143.2,2716.2c-42-17.7,12.9-75.8,47.7-48.5S6177.3,2730.6,6143.2,2716.2z"/>
                <path class="remove_credit_st5" d="M5735,3019c-20.2-28.7-134.1,12.5-118.2,40.9C5632.7,3088.3,5756.6,3049.7,5735,3019z"/>
                <path d="M5621,3230.8c0,0-8.3-48.5,73.5-50c81.9-1.5,88.7-27.3,136.4-30.3c47.7-3,70.5,9.9,70.5,9.9s-28.8,44-77.3,46.2 c-48.5,2.3-141.7-11.4-150.8,4.5S5621,3230.8,5621,3230.8z"/>
                <g id="remove_credit_eyes">
                    <path id="remove_credit_eye_1" d="M5450.5,2942.8c-57.9,19.3-113.7-92.8-45.5-116.1C5473.2,2803.4,5518.7,2920.1,5450.5,2942.8z"/>
                    <path id="remove_credit_eye_2" d="M5844.6,2792.8c83.4-34.2,7.6-177.3-66.7-145.5C5703.6,2679.1,5785.4,2817,5844.6,2792.8z"/>
                </g>
                <path d="M5867.3,2548c22-11.3-97-94-125.1-74.3c-28,19.7-12.1,43.2,35.6,54.6C5825.6,2539.6,5839.3,2562.4,5867.3,2548z"/>
                <path d="M5345.9,2690.2c-19.6-12.6-30.8,31.8-40.4,54.1c-9.6,22.2-22.7,50-2,54.6s47-0.5,47.5-29.8S5352.9,2694.7,5345.9,2690.2z" />
                <path class="remove_credit_st6" d="M5420.1,2444.9c0,0,227.1,438.8,336.4,857.2s113.5,454.3,113.5,454.3l-290.7,70.1c0,0-75.4-416.5-171.9-684.8 S5164.7,2551,5164.7,2551S5279.2,2557.4,5420.1,2444.9z"/>
                <path class="remove_credit_st5" d="M6054.5,2566.5c0,0-46.6-278.5-153.5-359.2c-106.9-80.7-260.3-109.1-347.9-10.2 c-87.5,98.9-248.2,282.7-406.6,325.9c-158.4,43.2-233.5-140.1-239.7-199.5c0,0-20.2,118.4,21.5,176.7 c41.7,58.3,158.4,106.1,240.7,61.6l-4.3-10.9c0,0,117.6,15.3,254.3-107.1c228.5-204.4,282-242.9,408.8-222.6 C5946.1,2240.3,6007.9,2409.6,6054.5,2566.5z"/>
            </g>
            <g id="remove_credit_arm_2">
                <path class="remove_credit_st7" d="M5747.5,4085.7l-1443.8-281.2l29.6-162.1L5779,3920.5c0,0,42.7,44.7,20.1,109.5 C5776.3,4094.8,5747.5,4085.7,5747.5,4085.7z"/>
            </g>
            <g id="remove_credit_body">
                <path class="remove_credit_st7" d="M6446.3,3617.3c0,0,109.1,339.5,157.6,836.7c48.5,497.2,64.4,587.4,44,637.4c-20.5,50-79.6,86.4-79.6,86.4 v1543.8h-241V5196.8h-214.5v1524.9h-245.9V5215c0,0-86-10.6-87.5-157.6c-1.5-147-124.3-980.7-200.1-1230.8L6446.3,3617.3z"/>
                <path class="remove_credit_st8" d="M6034,4607.2c0,0-219.1-634.1-443.8-745.7l-11-35l572.2-138.1L6034,4607.2z"/>
                <path class="remove_credit_st9" d="M5870,3886.4l2.7,341.6c0,0,156.8,340.5,161.3,379.2l51.3-401.3c0,0-94.5-270.6-137.7-337.7 c0,0,92.3-42.7,60.9-145.2l-229.6,55.4C5779,3778.4,5779,3921.5,5870,3886.4z"/>
                <path d="M6057.9,4732.2c-54.8,18.8-61.4-71.6-19.3-80.7S6094.3,4719.7,6057.9,4732.2z"/>
                <path d="M6079.7,4889.1c-48.3,20.8-59.3-63.7-25.2-75C6088.6,4802.7,6121.9,4870.9,6079.7,4889.1z"/>
                <path d="M6568.3,6721.7v209.2h-400.9c0,0-36.4-191,159.9-209.2H6568.3z"/>
                <path d="M6111.3,6930.9v-209.2H5865c0,0-171.3,43.2-159.2,209.2H6111.3z"/>
                <path class="remove_credit_st8" d="M6194.7,6852c-21.5-15.7,56.6-75.8,103.6-45C6345.3,6837.9,6228.1,6876.3,6194.7,6852z"/>
                <path class="remove_credit_st8" d="M5760.7,6857.6c-31.1-12.1,30.9-87.9,102.1-54.1C5917.8,6829.7,5802.1,6873.7,5760.7,6857.6z"/>
                <path class="remove_credit_st5" d="M5979.5,5230.1v1491.5H5865V5215c0,0-73.5,3.1-85.6-157.6c-12.1-160.8-191.3-1202.9-191.3-1202.9 s281.2,214.5,442.1,740.6c0,0,8.5,509.4,125.6,601.8h-42.8L5979.5,5230.1z"/>
                <g id="remove_credit_belt">
                    <polygon points="5775.5,4994 6650.5,4924.4 6654,4968.6 5779,5033.5 			"/>
                    <polygon class="remove_credit_st10" points="6001.7,5024.5 5997.7,4970.4 6168.9,4956.8 6168.9,5009.9 			"/>
                </g>
            </g>
            <g id="remove_credit_bag_with_arm">
                <g id="remove_credit_bag">
                    <path class="remove_credit_st11" d="M4580,2936.8l-79.6-11c0,0,37.4-44.2-31.8-51.2c-60.5-6.1-54.6,38.7-54.6,38.7l-983.4-194.1 c0,0,31.1-73.4-28.8-84.8c-59.9-11.4-48.5,60.6-48.5,60.6s-71.2-28-97.8-23.5s-142.5,800.7-144,880.1 c-1.5,79.4,106.1,81,210.7,90.8c104.6,9.8,157.6,18.9,157.6,18.9s-84.9,219.8-24.3,277.4c60.6,57.6,346.7,83.4,422.7,83.4 c76,0,173-260.7,173-260.7s225.9,39.4,292.5,33.3c66.7-6.1,71.3-95.7,100-203.1S4604.6,2968.6,4580,2936.8z"/>
                </g>
            </g>
        </g>
        <g mask="url(#window-mask)">
            <g id="use-dollar-1" style="transform-origin: center center; scale: 0.1; translate: -201px -850px; rotate: 5deg;">
                <use xlink:href="#dollar"></use>
            </g>
            <g id="use-dollar-2" style="transform-origin: center center; scale: 0.1; translate: -301px -850px;">
                <use xlink:href="#dollar" style="transform: rotate3d(1, 1, 1, 65deg);"></use>
            </g>
            <g id="use-dollar-3" style="transform-origin: center center; scale: 0.1; translate: -351px -850px;">
                <use xlink:href="#dollar" style="transform: rotate3d(1, 1, 1, -35deg);"></use>
            </g>
            <g id="use-dollar-4" style="transform-origin: center center; scale: 0.1; translate: -250px -850px;">
                <use xlink:href="#dollar" style="transform: rotate3d(1, 1, 1, 25deg);"></use>
            </g>
        </g>
        <g id="remove_credit_bag_top">
            <polygon class="remove_credit_st11" points="3143.4,3338.2 4440.9,3603.7 4578.7,3002.6 3233.3,2744.1 		"/>
            <path class="remove_credit_st12" d="M3548.1,3371.8c0,0-34.9-92.9,45.5-212.2c50-74.3,395.6,7.6,460.8,45.5c65.2,37.9,16.7,289.2,16.7,289.2 l383.2,58.2l-33.7,136l-1297.5-246.7l18.3-136.9L3548.1,3371.8z M3630,3386.2l350.9,78.1c0,0,25.8-135.7,20.5-169.8 c-5.3-34.1-59.1-47.7-162.9-63.7s-162.2-31.8-184.2-1.5C3632.3,3259.6,3630,3386.2,3630,3386.2z"/>
        </g>
        <g id="remove_credit_arm_1">
            <path class="remove_credit_st7" d="M6413.7,3730.7l-1646.9-352.8l-22.7,176.4l1608.3,352.6c0,0,83,5.7,98.9-73.9 C6467.2,3753.4,6413.7,3730.7,6413.7,3730.7z"/>
            <path class="remove_credit_st8" d="M4658.5,3337.7l128.1,20.5l-37.1,209.9c0,0-101.6-0.8-112.9-35.6C4625.1,3497.6,4658.5,3337.7,4658.5,3337.7z "/>
            <path d="M4710,3533.2c-31.8,15.2-76.1-24.3-34.1-56.1C4703.9,3455.9,4746.4,3515.8,4710,3533.2z"/>
            <path class="remove_credit_st3" d="M4670.3,3352.1c0,0-28.5,3-33.9-41.7c-5.3-44.7-12.1-56.1-112.2-81.9c-100-25.8-150.8-33.3-158.4-18.2 c-7.6,15.2,9.9,35.6,59.1,44c49.3,8.3,83.4,8.3,78.8,27.3c-4.5,18.9-44,6.8-111.4-9.9c-67.5-16.7-209.2-61.4-220.5-32.6 c-11.4,28.8,188.7,47.7,183.4,69c-5.3,21.2-204.6-42.4-210.7-14.4c-6.1,28,50.8,34.1,105.3,40.2c54.6,6.1,98.5,8.3,93.2,30.3 c-5.3,22-197.2-33.3-201.3-14.4c-4.1,18.9,31.5,28,77.8,35.6c46.2,7.6,119,12.9,115.2,34.1c-3.8,21.2-159.2-34.9-165.2-13.6 c-6.1,21.2,37.1,35.6,70.5,41.7c33.3,6.1,261.5,44,319.1,46.2s89.4-4.5,89.4-4.5L4670.3,3352.1z"/>
        </g>    
        <g id="remove_credit_teller_window_top">
            <path class="remove_credit_st11" d="M1711,5121h3568.2c0,0,96.6,9.1,96.6,103.5s-104.6,104.6-104.6,104.6H1711c0,0-105.5,12.1-105.5-105.5 S1711,5121,1711,5121z"/>
            <path class="remove_credit_st13" d="M2114.7,5192.8c0,25,12,32.1,40.4,32.1c28.4,0,40.9,0,54.6,0s30.3-8.3,30.3-26.5s-15.9-29.6-27.3-29.6 s-52.3,0-65.9,0C2122.3,5168.8,2114.7,5192.8,2114.7,5192.8z"/>
            <path class="remove_credit_st13" d="M2332.5,5196.6c0-21.3,7.6-27.9,41.9-27.9s2819.9,0,2857.8,0c37.9,0,53.1,56.1,0,56.1s-2825.8,0-2861.1,0 S2332.5,5218.4,2332.5,5196.6z"/>
        </g>
    </g>
</symbol>
`;

==> western-world-3.0.655.tgz: package/src/defs/remove_credit/remove_credit.js <==
const style = require('!!css-loader!sass-loader!./remove_credit.scss').default;

export const remove_credit = `
<pattern id="bricks_pattern_2" viewBox="0 0 8192 8192" width="50%" height="50%">
    <use xlink:href="#bricks" x="0" y="0" style="--brick-color-0:white;--brick-color-1:#e7e7e7;--brick-color-2:#fbfbfb;--brick-color-3:#f0f0f0;--brick-color-4:#e3e3e3;"></use>
</pattern>
<mask id="window-mask">
    <path fill="white" d="M1883.8,5121c0,0,1.3-379.8,0-1265.8c-3.5-2332.7,2992-2302.3,2980.5-222.7c-7.9,1430.1,0,1488.5,0,1488.5 H1883.8z"/>
</mask>
<symbol id="remove_credit" x="0px" y="0px" viewBox="0 0 8192 8192">
    <style type="text/css">
        .remove_credit_st1{fill:#818181;}
        .remove_credit_st2{fill:#592919;}
        .remove_credit_st3{fill:#F6D5A9;}
        .remove_credit_st4{fill:#704415;}
        .remove_credit_st5{opacity:0.2;}
        .remove_credit_st6{opacity:5.000000e-02;}
        .remove_credit_st7{fill:#494B4D;}
        .remove_credit_st8{fill:#FFFFFF;}
        .remove_credit_st9{fill:#C20C2C;}
        .remove_credit_st10{fill:#9E9E9E;}
        .remove_credit_st12{fill:#7B594C;}
        ${style}
    </style>

    <g id="remove_credit-main-container">
        <g id="remove_credit_background">
            <circle cx="4096" cy="4096" r="3700" fill="#c1c1c1" />
            <circle cx="4096" cy="4096" r="3700" fill="url(#bricks_pattern_2)" />
        </g>
        <g id="remove_credit_teller_window">
            <path class="remove_credit_st1" d="M1883.8,5121c0,0,1.3-379.8,0-1265.8c-3.5-2332.7,2992-2302.3,2980.5-222.7c-7.9,1430.1,0,1488.5,0,1488.5 H1883.8z"/>
        </g>
        <g id="remove_credit_title">
            <path class="remove_credit_st7" d="M2676.6,1931.7c16.7,30.1,8.2,66.7-25.6,109.7c-32.7,41.3-80.2,79.3-142.6,113.9c-28.3,15.7-55,28.3-80.3,37.6 c-25.2,9.4-49.8,15.6-73.7,18.7l-128.7-231.8c25.6-21.5,51.1-41.4,76.4-59.6c25.3-18.2,51.9-35,79.7-50.5 c47.9-26.6,87.7-42.5,119.4-47.8c34.9-5.8,58.1,1.6,69.5,22.1c4.7,8.5,4.6,19-0.5,31.3c-5.1,12.3-21,33.5-47.7,63.6 c34.4-16.3,65.6-25.6,93.7-28C2647.3,1908.4,2667.4,1915.3,2676.6,1931.7z M2445.7,1918.9c-4.1-7.3-11.9-10.2-23.5-8.6 c-11.6,1.6-25.1,6.7-40.5,15.2c-18.3,10.1-32.3,20.6-42,31.4l26,46.8c5.2-0.6,11.2-2.8,18.1-6.7c18.7-10.4,35-23.7,48.8-40 C2446.4,1940.8,2450.8,1928.1,2445.7,1918.9z M2544.9,2010.2c-3.9-7.1-12.7-10.2-26.2-9.5c-13.6,0.7-26.8,4.7-39.7,11.9 c-4,2.2-7.9,4.9-11.7,8l29,52.2c4.1-1.6,9.2-4.1,15.4-7.6c14.7-8.2,25.1-17.3,31.1-27.5C2548.7,2027.5,2549.4,2018.4,2544.9,2010.2 z"/>
            <path class="remove_credit_st7" d="M3310,1851.4l-155.1,94l-76.4-56.4l-90.1,37.3l-44,78.9l-172.2-13.6l121.6-347l135.3-9.5L3310,1851.4z M3065.6,1835.2l-82.3-96.1l-22.1,121.1L3065.6,1835.2z"/>
            <path class="remove_credit_st7" d="M3865.1,1956.8l-244-224.4l44.7,173.8l-241.9-22.6l62.5-328.8l258.5,174.6l-14-139.1l187.9,83.5L3865.1,1956.8 z"/>
            <path class="remove_credit_st7" d="M4475.6,2163.3l-137.6,12.7l-120.7-201.7l-27.3,75.2l-205.6-75.7l134.7-283.2l205,94.7l-80,77.5l221.8-27 l66.2,117.1l-184.5,15.1L4475.6,2163.3z"/>
        </g>
        <g id="remove_credit_person">
            <g id="remove_credit_head">
                <path class="remove_credit_st3" d="M5164.7,2551c0,0,290.3,611.6,414.6,1275.5l867-209.2c0,0-124.3-568.4-257.7-868.5c0,0,77.3,1.5,83.4-103.1 s-111.9-108.5-162.2-83.4c-33.3,16.7-45.5,59.1-45.5,59.1s-45.5-280.4-168.3-369.9c-122.8-89.4-289.5,15.2-347.1,80.3 S5304.9,2559.3,5164.7,2551z"/>
                <path class="remove_credit_st4" d="M4988.1,2217c0,0-105.2,27.3-84.9,213.5c13.6,125.1,169,148.5,169,148.5s78.2,228.1,207.9,243.1 c0,0-102.9-254.1-115.4-271.1c0,0,97.4,16.7,255.4-106.1c158-122.8,201.2-227.4,386.5-226.2c185.3,1.1,257.7,402.8,257.7,402.8 s15.9-73.1,102.1-71.9c0,0,55.6-347.8-118.8-502.6c-90.9-80.7-203.5-38.7-203.5-38.7s-45.5-172.8-291-148.9 c-200.3,19.5-383.1,303.5-411.5,386.5C5113.2,2328.9,4966.5,2360.9,4988.1,2217z"/>
                <path class="remove_credit_st5" d="M6143.2,2716.2c-42-17.7,12.9-75.8,47.7-48.5S6177.3,2730.6,6143.2,2716.2z"/>
                <path class="remove_credit_st5" d="M5735,3019c-20.2-28.7-134.1,12.5-118.2,40.9C5632.7,3088.3,5756.6,3049.7,5735,3019z"/>
                <path d="M5621,3230.8c0,0-8.3-48.5,73.5-50c81.9-1.5,88.7-27.3,136.4-30.3c47.7-3,70.5,9.9,70.5,9.9s-28.8,44-77.3,46.2 c-48.5,2.3-141.7-11.4-150.8,4.5S5621,3230.8,5621,3230.8z"/>
                <g id="remove_credit_eyes">
                    <path id="remove_credit_eye_1" d="M5450.5,2942.8c-57.9,19.3-113.7-92.8-45.5-116.1C5473.2,2803.4,5518.7,2920.1,5450.5,2942.8z"/>
                    <path id="remove_credit_eye_2" d="M5844.6,2792.8c83.4-34.2,7.6-177.3-66.7-145.5C5703.6,2679.1,5785.4,2817,5844.6,2792.8z"/>
                </g>
                <path d="M5867.3,2548c22-11.3-97-94-125.1-74.3c-28,19.7-12.1,43.2,35.6,54.6C5825.6,2539.6,5839.3,2562.4,5867.3,2548z"/>
                <path d="M5345.9,2690.2c-19.6-12.6-30.8,31.8-40.4,54.1c-9.6,22.2-22.7,50-2,54.6s47-0.5,47.5-29.8S5352.9,2694.7,5345.9,2690.2z" />
                <path class="remove_credit_st6" d="M5420.1,2444.9c0,0,227.1,438.8,336.4,857.2s113.5,454.3,113.5,454.3l-290.7,70.1c0,0-75.4-416.5-171.9-684.8 S5164.7,2551,5164.7,2551S5279.2,2557.4,5420.1,2444.9z"/>
                <path class="remove_credit_st5" d="M6054.5,2566.5c0,0-46.6-278.5-153.5-359.2c-106.9-80.7-260.3-109.1-347.9-10.2 c-87.5,98.9-248.2,282.7-406.6,325.9c-158.4,43.2-233.5-140.1-239.7-199.5c0,0-20.2,118.4,21.5,176.7 c41.7,58.3,158.4,106.1,240.7,61.6l-4.3-10.9c0,0,117.6,15.3,254.3-107.1c228.5-204.4,282-242.9,408.8-222.6 C5946.1,2240.3,6007.9,2409.6,6054.5,2566.5z"/>
            </g>
            <g id="remove_credit_arm_2">
                <path class="remove_credit_st7" d="M5747.5,4085.7l-1443.8-281.2l29.6-162.1L5779,3920.5c0,0,42.7,44.7,20.1,109.5 C5776.3,4094.8,5747.5,4085.7,5747.5,4085.7z"/>
            </g>
            <g id="remove_credit_body">
                <path class="remove_credit_st7" d="M6446.3,3617.3c0,0,109.1,339.5,157.6,836.7c48.5,497.2,64.4,587.4,44,637.4c-20.5,50-79.6,86.4-79.6,86.4 v1543.8h-241V5196.8h-214.5v1524.9h-245.9V5215c0,0-86-10.6-87.5-157.6c-1.5-147-124.3-980.7-200.1-1230.8L6446.3,3617.3z"/>
                <path class="remove_credit_st8" d="M6034,4607.2c0,0-219.1-634.1-443.8-745.7l-11-35l572.2-138.1L6034,4607.2z"/>
                <path class="remove_credit_st9" d="M5870,3886.4l2.7,341.6c0,0,156.8,340.5,161.3,379.2l51.3-401.3c0,0-94.5-270.6-137.7-337.7 c0,0,92.3-42.7,60.9-145.2l-229.6,55.4C5779,3778.4,5779,3921.5,5870,3886.4z"/>
                <path d="M6057.9,4732.2c-54.8,18.8-61.4-71.6-19.3-80.7S6094.3,4719.7,6057.9,4732.2z"/>
                <path d="M6079.7,4889.1c-48.3,20.8-59.3-63.7-25.2-75C6088.6,4802.7,6121.9,4870.9,6079.7,4889.1z"/>
                <path d="M6568.3,6721.7v209.2h-400.9c0,0-36.4-191,159.9-209.2H6568.3z"/>
                <path d="M6111.3,6930.9v-209.2H5865c0,0-171.3,43.2-159.2,209.2H6111.3z"/>
                <path class="remove_credit_st8" d="M6194.7,6852c-21.5-15.7,56.6-75.8,103.6-45C6345.3,6837.9,6228.1,6876.3,6194.7,6852z"/>
                <path class="remove_credit_st8" d="M5760.7,6857.6c-31.1-12.1,30.9-87.9,102.1-54.1C5917.8,6829.7,5802.1,6873.7,5760.7,6857.6z"/>
                <path class="remove_credit_st5" d="M5979.5,5230.1v1491.5H5865V5215c0,0-73.5,3.1-85.6-157.6c-12.1-160.8-191.3-1202.9-191.3-1202.9 s281.2,214.5,442.1,740.6c0,0,8.5,509.4,125.6,601.8h-42.8L5979.5,5230.1z"/>
                <g id="remove_credit_belt">
                    <polygon points="5775.5,4994 6650.5,4924.4 6654,4968.6 5779,5033.5 			"/>
                    <polygon class="remove_credit_st10" points="6001.7,5024.5 5997.7,4970.4 6168.9,4956.8 6168.9,5009.9 			"/>
                </g>
            </g>
            <g id="remove_credit_bag_with_arm">
                <g id="remove_credit_bag">
                    <path class="remove_credit_st2" d="M4580,2936.8l-79.6-11c0,0,37.4-44.2-31.8-51.2c-60.5-6.1-54.6,38.7-54.6,38.7l-983.4-194.1 c0,0,31.1-73.4-28.8-84.8c-59.9-11.4-48.5,60.6-48.5,60.6s-71.2-28-97.8-23.5s-142.5,800.7-144,880.1 c-1.5,79.4,106.1,81,210.7,90.8c104.6,9.8,157.6,18.9,157.6,18.9s-84.9,219.8-24.3,277.4c60.6,57.6,346.7,83.4,422.7,83.4 c76,0,173-260.7,173-260.7s225.9,39.4,292.5,33.3c66.7-6.1,71.3-95.7,100-203.1S4604.6,2968.6,4580,2936.8z"/>
                </g>
            </g>
        </g>
        <g mask="url(#window-mask)">
            <g id="use-dollar-1" style="transform-origin: center center; scale: 0.1; translate: -201px -850px; rotate: 5deg;">
                <use xlink:href="#dollar"></use>
            </g>
            <g id="use-dollar-2" style="transform-origin: center center; scale: 0.1; translate: -301px -850px;">
                <use xlink:href="#dollar" style="transform: rotate3d(1, 1, 1, 65deg);"></use>
            </g>
            <g id="use-dollar-3" style="transform-origin: center center; scale: 0.1; translate: -351px -850px;">
                <use xlink:href="#dollar" style="transform: rotate3d(1, 1, 1, -35deg);"></use>
            </g>
            <g id="use-dollar-4" style="transform-origin: center center; scale: 0.1; translate: -250px -850px;">
                <use xlink:href="#dollar" style="transform: rotate3d(1, 1, 1, 25deg);"></use>
            </g>
        </g>
        <g id="remove_credit_bag_top">
            <polygon class="remove_credit_st2" points="3143.4,3338.2 4440.9,3603.7 4578.7,3002.6 3233.3,2744.1 		"/>
            <path class="remove_credit_st12" d="M3548.1,3371.8c0,0-34.9-92.9,45.5-212.2c50-74.3,395.6,7.6,460.8,45.5c65.2,37.9,16.7,289.2,16.7,289.2 l383.2,58.2l-33.7,136l-1297.5-246.7l18.3-136.9L3548.1,3371.8z M3630,3386.2l350.9,78.1c0,0,25.8-135.7,20.5-169.8 c-5.3-34.1-59.1-47.7-162.9-63.7s-162.2-31.8-184.2-1.5C3632.3,3259.6,3630,3386.2,3630,3386.2z"/>
        </g>
        <g id="remove_credit_arm_1">
            <path class="remove_credit_st7" d="M6413.7,3730.7l-1646.9-352.8l-22.7,176.4l1608.3,352.6c0,0,83,5.7,98.9-73.9 C6467.2,3753.4,6413.7,3730.7,6413.7,3730.7z"/>
            <path class="remove_credit_st8" d="M4658.5,3337.7l128.1,20.5l-37.1,209.9c0,0-101.6-0.8-112.9-35.6C4625.1,3497.6,4658.5,3337.7,4658.5,3337.7z "/>
            <path d="M4710,3533.2c-31.8,15.2-76.1-24.3-34.1-56.1C4703.9,3455.9,4746.4,3515.8,4710,3533.2z"/>
            <path class="remove_credit_st3" d="M4670.3,3352.1c0,0-28.5,3-33.9-41.7c-5.3-44.7-12.1-56.1-112.2-81.9c-100-25.8-150.8-33.3-158.4-18.2 c-7.6,15.2,9.9,35.6,59.1,44c49.3,8.3,83.4,8.3,78.8,27.3c-4.5,18.9-44,6.8-111.4-9.9c-67.5-16.7-209.2-61.4-220.5-32.6 c-11.4,28.8,188.7,47.7,183.4,69c-5.3,21.2-204.6-42.4-210.7-14.4c-6.1,28,50.8,34.1,105.3,40.2c54.6,6.1,98.5,8.3,93.2,30.3 c-5.3,22-197.2-33.3-201.3-14.4c-4.1,18.9,31.5,28,77.8,35.6c46.2,7.6,119,12.9,115.2,34.1c-3.8,21.2-159.2-34.9-165.2-13.6 c-6.1,21.2,37.1,35.6,70.5,41.7c33.3,6.1,261.5,44,319.1,46.2s89.4-4.5,89.4-4.5L4670.3,3352.1z"/>
        </g>    
        <g id="remove_credit_teller_window_top">
            <path class="remove_credit_st7" d="M1711,5121h3568.2c0,0,96.6,9.1,96.6,103.5s-104.6,104.6-104.6,104.6H1711c0,0-105.5,12.1-105.5-105.5 S1711,5121,1711,5121z"/>
            <path class="remove_credit_st1" d="M2114.7,5192.8c0,25,12,32.1,40.4,32.1c28.4,0,40.9,0,54.6,0s30.3-8.3,30.3-26.5s-15.9-29.6-27.3-29.6 s-52.3,0-65.9,0C2122.3,5168.8,2114.7,5192.8,2114.7,5192.8z"/>
            <path class="remove_credit_st1" d="M2332.5,5196.6c0-21.3,7.6-27.9,41.9-27.9s2819.9,0,2857.8,0c37.9,0,53.1,56.1,0,56.1s-2825.8,0-2861.1,0 S2332.5,5218.4,2332.5,5196.6z"/>
        </g>
    </g>
</symbol>
`;
